import * as React from 'react';
import { MonthsDropdown, Navigation, YearsDropdown } from '../../components';
import { useDayPicker, useNavigation } from '../../hooks';
import { UIElement as UI } from '../../types';
/**
 * Render the caption of a month, which includes title and navigation buttons.
 * The caption has a different layout when setting the `numberOfMonths` prop.
 */
export function Caption(props) {
    var displayMonth = props.displayMonth, isFirst = props.isFirst, isLast = props.isLast;
    var context = useDayPicker();
    var classNames = context.classNames, numberOfMonths = context.numberOfMonths, disableNavigation = context.disableNavigation, styles = context.styles, captionLayout = context.captionLayout, onMonthChange = context.onMonthChange, CaptionLabel = context.components.CaptionLabel;
    var _a = useNavigation(), previousMonth = _a.previousMonth, nextMonth = _a.nextMonth, setMonth = _a.setMonth;
    var handlePreviousClick = function (e) {
        if (!previousMonth)
            return;
        setMonth(previousMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(previousMonth);
    };
    var handleNextClick = function (e) {
        if (!nextMonth)
            return;
        setMonth(nextMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(nextMonth);
    };
    var handleMonthChange = function (newMonth) {
        setMonth(newMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(newMonth);
    };
    var captionLabel = React.createElement(CaptionLabel, { displayMonth: displayMonth });
    return (React.createElement("div", { className: classNames[UI.Caption], style: styles[UI.Caption] }, disableNavigation ? (captionLabel) : (React.createElement(React.Fragment, null, captionLayout === 'dropdown' ? (React.createElement("div", { className: classNames[UI.CaptionDropdowns], style: styles[UI.CaptionDropdowns] },
        React.createElement(MonthsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth }),
        React.createElement(YearsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth }))) : (React.createElement(React.Fragment, null,
        React.createElement(CaptionLabel, { displayMonth: displayMonth }),
        React.createElement(Navigation, { displayMonth: displayMonth, hideNext: numberOfMonths > 1 && !isLast, hidePrevious: numberOfMonths > 1 && !isFirst, disableNext: !nextMonth, disablePrevious: !previousMonth, onPreviousClick: handlePreviousClick, onNextClick: handleNextClick })))))));
}
//# sourceMappingURL=Caption.js.map