var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { isSameDay, isSameMonth } from 'date-fns';
import { useDayPicker, useModifiers, useSelection } from '../../hooks';
import { formatDay } from '../../hooks/useDayPicker/formatters';
import { useFocus } from '../../hooks/useFocus';
import { UIElement } from '../../types';
import { createHandlers } from './utils/createHandlers';
/**
 * Render the content of a date cell, as a button or span element according to
 * its modifiers. Attaches the event handlers from DayPicker context, and manage the
 * focused date.
 */
export function Day(props) {
    var buttonRef = React.useRef(null);
    var date = props.date, displayMonth = props.displayMonth;
    var context = useDayPicker();
    var selection = useSelection();
    var modifierStatus = useModifiers(date);
    var _a = useFocus(), focusedDay = _a[0], _b = _a[1], focusDayAfter = _b.focusDayAfter, focusDayBefore = _b.focusDayBefore, focusDayDown = _b.focusDayDown, focusDayUp = _b.focusDayUp, blur = _b.blur, focus = _b.focus;
    var classNames = context.classNames, labelDay = context.labels.labelDay, DayContent = context.components.DayContent, locale = context.locale, modifierClassNames = context.modifierClassNames, modifierPrefix = context.modifierPrefix, modifierStyles = context.modifierStyles, showOutsideDays = context.showOutsideDays, styles = context.styles, onDayClick = context.onDayClick, mode = context.mode;
    React.useEffect(function () {
        var _a;
        if (!focusedDay)
            return;
        if (isSameDay(focusedDay, date)) {
            (_a = buttonRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
    }, [focusedDay]);
    if (modifierStatus.hidden)
        return React.createElement("span", null);
    var ariaLabel = labelDay(date, modifierStatus, { locale: locale });
    var ariaPressed = modifierStatus.selected;
    var handleClick = function (e) {
        var _a, _b;
        if (mode !== 'uncontrolled') {
            (_b = (_a = selection[mode]).onDayClick) === null || _b === void 0 ? void 0 : _b.call(_a, date, modifierStatus, e);
        }
        onDayClick === null || onDayClick === void 0 ? void 0 : onDayClick(date, modifierStatus, e);
    };
    var handleFocus = function (e) {
        focus(date);
    };
    var handleBlur = function (e) {
        blur();
    };
    var handleKeyDown = function (e) {
        switch (e.key) {
            case 'ArrowLeft':
                e.preventDefault();
                e.stopPropagation();
                focusDayBefore();
                break;
            case 'ArrowRight':
                e.preventDefault();
                e.stopPropagation();
                focusDayAfter();
                break;
            case 'ArrowDown':
                e.preventDefault();
                e.stopPropagation();
                focusDayDown();
                break;
            case 'ArrowUp':
                e.preventDefault();
                e.stopPropagation();
                focusDayUp();
                break;
        }
    };
    var otherEventHandlers = createHandlers(date, modifierStatus, context);
    var buttonClassNames = [classNames[UIElement.Day]];
    var isOutside = !isSameMonth(date, displayMonth);
    if (isOutside) {
        buttonClassNames.push(classNames[UIElement.Outside]);
    }
    var isToday = isSameDay(date, context.today);
    if (isToday) {
        buttonClassNames.push(classNames[UIElement.Today]);
    }
    Object.keys(modifierStatus)
        .filter(function (modifier) { return Boolean(modifierStatus[modifier]); })
        .forEach(function (modifier) {
        if (modifierClassNames[modifier]) {
            buttonClassNames.push(modifierClassNames[modifier]);
        }
        else {
            buttonClassNames.push("" + modifierPrefix + modifier);
        }
    });
    var style = __assign({}, styles[UIElement.Day]);
    if (styles) {
        Object.keys(modifierStatus).forEach(function (modifier) { return (style = __assign(__assign({}, style), styles[modifier])); });
    }
    if (modifierStyles) {
        Object.keys(modifierStatus).forEach(function (modifier) { return (style = __assign(__assign({}, style), modifierStyles[modifier])); });
    }
    var dayContent = (React.createElement(DayContent, { "aria-label": ariaLabel, hiddenClassName: classNames[UIElement.Hidden], date: date, modifiers: modifierStatus, showOutsideDays: showOutsideDays, outside: isOutside, format: formatDay, locale: locale, displayMonth: displayMonth }));
    var className = buttonClassNames.join(' ');
    if (modifierStatus.disabled || isOutside) {
        return (React.createElement("span", { style: style, className: className }, dayContent));
    }
    var tabIndex = 0;
    // When a day is focused disable tab indexes in the other days
    if (focusedDay && !isSameDay(focusedDay, date))
        tabIndex = -1;
    return (React.createElement("button", __assign({ ref: buttonRef, "aria-pressed": ariaPressed, style: style, className: className, tabIndex: tabIndex, onClick: handleClick, onFocus: handleFocus, onBlur: handleBlur, onKeyDown: handleKeyDown }, otherEventHandlers), dayContent));
}
//# sourceMappingURL=Day.js.map