import * as React from 'react';
import { isSameMonth } from 'date-fns';
import { useDayPicker } from '../useDayPicker';
import { getDisplayMonths } from './utils/getDisplayMonths';
import { getInitialMonth } from './utils/getInitialMonth';
import { getNextMonth } from './utils/getNextMonth';
import { getPreviousMonth } from './utils/getPreviousMonth';
/** The navigation context holds values and setters for navigating between the
 * calendars. */
export var NavigationContext = React.createContext(undefined);
/** Provides the values for the [[NavigationContext]]. */
export var NavigationProvider = function (_a) {
    var children = _a.children;
    var context = useDayPicker();
    var initialMonth = getInitialMonth(context);
    var _b = React.useState(initialMonth), month = _b[0], setMonthInternal = _b[1];
    var setMonth = function (date) {
        if (context.disableNavigation)
            return;
        setMonthInternal(date);
    };
    React.useEffect(function () {
        if (!context.month)
            return;
        if (isSameMonth(context.month, month))
            return;
        setMonth(context.month);
    }, [context.month]);
    var displayMonths = getDisplayMonths(month, context);
    var nextMonth = getNextMonth(month, context);
    var previousMonth = getPreviousMonth(month, context);
    return (React.createElement(NavigationContext.Provider, { value: { month: month, displayMonths: displayMonths, setMonth: setMonth, previousMonth: previousMonth, nextMonth: nextMonth } }, children));
};
//# sourceMappingURL=NavigationContext.js.map